@@ -5,7 +5,7 @@ use strictures 1;
 
 use App::Cmd::Setup-command;
 
-use Log::Any::Adapter qw<ScreenColoredLevel>;
+use Log::Any::Adapter qw<Screen>;
 use File::HomeDir qw<>;
 use File::Temp qw<>;
 use JSON qw<>;
@@ -13,7 +13,7 @@ use Path::Class qw<>;
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.1.0';
+our $VERSION = 'v1.1.3';
 
 my %config;
 
