@@ -15,12 +15,12 @@ use Types::Path::Tiny qw( Dir File Path );
 use Path::Tiny;
 use Try::Tiny;
 use Template::Tiny;
-use File::ShareDir::ProjectDistDir;
+use File::ShareDir qw(dist_dir);
 
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.1.0';
+our $VERSION = 'v1.1.3';
 
 # permit callers to sloppily pass undefined hash values
 sub BUILDARGS
